---
title: <span class="badge object-type-scalar"></span> HashesPerSecond
---
# <span class="badge object-type-scalar"></span> HashesPerSecond

Hash rate: hashes/sec

## Definition

```python
# Hash rate: hashes/sec
HashesPerSecond: typing.Literal["Hs"] = "Hs"
```
